From 0aa39e22a2bb1bbcb8a02dfd6635ffe4d8a0bbb1 Mon Sep 17 00:00:00 2001
From: Andreas Sturmlechner <asturm@gentoo.org>
Date: Sat, 27 Nov 2021 14:43:18 +0100
Subject: [PATCH] Add CMake option to build WITHOUT_X11

We want to be able to build without X11 support even if some of the used
libraries may not work w/o X11 themselves yet or need to be built with
X11 support for other reverse dependencies.

HAVE_X11 already exists and is set automagically so far, but using
-DCMAKE_DISABLE_FIND_PACKAGE_X11 will break if any dependencies list X11
as required in their cmake config.

Introducing this option means there is no behavior change by default,
cmake will just skip finding X11 or adding unwanted features if the
option is enabled.

Signed-off-by: Andreas Sturmlechner <asturm@gentoo.org>
---
 CMakeLists.txt | 9 ++++++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index 61ed70cd7..565682848 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -103,10 +103,13 @@ set_package_properties(KF5DocTools PROPERTIES DESCRIPTION
 )
 
 if(NOT APPLE)
-    find_package(X11)
-    set_package_properties(X11 PROPERTIES TYPE OPTIONAL)
+    option(WITHOUT_X11 "Build without X11 integration (skips finding X11)" OFF)
+    if (NOT WITHOUT_X11)
+        find_package(X11)
+        set_package_properties(X11 PROPERTIES TYPE OPTIONAL)
+        set(HAVE_X11 ${X11_FOUND})
+    endif()
 endif()
-set(HAVE_X11 ${X11_FOUND})
 
 # Check for function GETPWUID
 check_symbol_exists(getpwuid "pwd.h" HAVE_GETPWUID)
-- 
GitLab

